@charset "UTF-8";
:root {
  --cassiopeia-color-primary: #112855;
  --cassiopeia-color-link: #224faa;
  --link-color: #224faa;
  --link-color-rgb: 34, 79, 170;
  --cassiopeia-color-hover: #424077;
  --link-hover-color: #424077;
  --link-hover-color-rgb: 66, 64, 119;
}
