// Collapse

.accordion {

  .card-header {
    display: block;
    font-size: $h5-font-size;
    font-weight: var(--cassiopeia-font-weight-headings, $font-weight-bold);
    line-height: $headings-line-height;
  }

  .list-group-item {
    color: $link-color;
  }

}
