// Fonts
$roboto-font-path: "../../../../../vendor/roboto-fontface/fonts" !default;
@import "../../../../../vendor/roboto-fontface/scss/roboto/sass/roboto-fontface";

:root {
  --cassiopeia-font-family-body: "Roboto", sans-serif;
  --cassiopeia-font-family-headings: "Roboto", sans-serif;
  --cassiopeia-font-weight-headings: 700;
  --cassiopeia-font-weight-normal: 400;
}
