// Tabs

.nav.nav-tabs {
  padding: 0;
  margin: 0;
  background-color: $cassiopeia-tabs-header-bg;
  border: 1px solid $cassiopeia-border-color;
  border-bottom: 0;
  border-radius: $border-radius $border-radius 0 0;
  box-shadow: 0 1px $white inset, 0 2px 3px -3px hsla(0, 0%, 0%, .15), 0 -4px 0 hsla(0, 0%, 0%, .05) inset, $cassiopeia-box-shadow;

  .nav-item {
    margin-bottom: 0;
    margin-left: 0;

    &:first-of-type .nav-link {

      &.active {
        border-radius: $border-radius 0 0;
        box-shadow: -1px 0 1px -1px hsla(0, 0%, 0%, .06), inset -2px 0 1px -1px hsla(0, 0%, 0%, .08), inset 0 1px 0 hsla(0, 0%, 0%, .02);
      }

    }

    &:last-of-type .nav-link {
      box-shadow: -1px 0 0 hsla(0, 0%, 0%, .05), 1px 0 0 hsla(0, 0%, 0%, .05);

      &.active {
        box-shadow: inset 2px 0 1px -1px hsla(0, 0%, 0%, .08), inset -2px 0 1px -1px hsla(0, 0%, 0%, .08), inset 0 1px 0 hsla(0, 0%, 0%, .02);
      }

    }

  }

  .nav-link {
    position: relative;
    padding: .75em 1em;
    color: var(--cassiopeia-color-primary);
    border: 0;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    box-shadow: -1px 0 0 hsla(0, 0%, 0%, .05);

    &.active {
      background-color: $cassiopeia-tabs-active-bg;
      background-image: linear-gradient(to bottom, hsla(0, 0%, 0%,0), hsla(0, 0%, 0%, .05) 100%);
      border-right: 0;
      border-left: 0;
      border-top-left-radius: 0;
      border-top-right-radius: 0;
      box-shadow: inset 2px 0 1px -1px hsla(0, 0%, 0%, .08), inset -2px 0 1px -1px hsla(0, 0%, 0%, .08), inset 0 1px 0 hsla(0, 0%, 0%, .02);

      &::after {
        position: absolute;
        right: 0;
        bottom: -1px;
        left: 0;
        height: 5px;
        content: "";
        background-color: $cassiopeia-tabs-active-highlight;
        opacity: .8;
      }

    }

  }

}

.nav-tabs + .tab-content {
  padding: 15px;
  background: $white;
  border: 1px solid;
  border-color: $cassiopeia-border-color;
  border-radius: 0 0 $border-radius $border-radius;
  box-shadow: $cassiopeia-box-shadow;
}
